Helper function for building GLM object with transformed variables.
build_xspliner(formula, model, data, xf_opts = xf_opts_default,
xs_opts = xs_opts_default, link = "identity", family = "gaussian",
env = parent.frame(), compare_stat = aic, control, ...)xspliner-specific formula object. Check vignette("xspliner") for more details.
Predictive model. Basic model used for extracting predictors transformation.
Training data of model.
Formula parameters used for factor variable transformations inherited from factorMerger package.
Predictive model response method and approximation parameters used for quantitative.
Link function that should be used in final model. The passed is used when cannot be extracted from model. By default 'identity'. See family for possibilities.
Family of response variable that should be used in final model. The passed is used when cannot be extracted from model. By default 'gaussian'. See family for possibilities.
Environment in which optional variables passed into parameters are stored.
Function of linear model (lm function output). Statistic that measures if linear model is better that transformed one. See stats.
Fitting settings. See glm.control.
Another parameters passed from chosen method. Not used.